@@ -27,22 +27,30 @@
 #include <kurl.h>
 #include <kfileitem.h>
 
+class QPushButton;
+
 class KatalogTest : public QWidget
 {
    Q_OBJECT
 public:
    KatalogTest( QWidget *parent=0, const char *name=0 );
    ~KatalogTest();
+  void customEvent( QCustomEvent * e );
 
 public slots:
    void test();
    void start1();
    void start2();
    void start3();
-   void slotFinished();
+   void start4();
+   void slotFinished(QString);
+   void slotCurrentFolder(QString);
+   void slotNewItem();
 
 private:
-   Katalog *k;
+   int m_items;
+   QPushButton* p_start3;
+   int count;
 };
 
 #endif
